#===========================================================
#
# Procedure: cn_tabelle_sort
#
# Purpose: Fallende Sortierung der Tabelle
#
# Preconditions:
#  Tabelle ist mit regulren Werten gefllt.
#  
#
# Postconditions:       
#  Sortierung erfolgt fallend nach - Mannschaftspunkte, Brettpunkte
#            
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_tabelle_sort { ArrayTabelle } {

   upvar $ArrayTabelle Tabelle

   # Bilden eines Hilfsarrays zum Sortieren
   # Schlssel: Mannschaftspunkte*10000 + Brettpunkte*10+Startnummer/10
   foreach k [array names Tabelle] {
      set mpkt [lindex $Tabelle($k) 7]
      set bpkt [lindex $Tabelle($k) 6]
      set wert [expr 10000.0*$mpkt+10.0*$bpkt+$k*1.0/10]
      set hilf($wert) $k
      set HTabelle($k) $Tabelle($k)
   }

   # Umsortieren des Hilfsfeldes und damit der Tabelle
   set i 1
   foreach j [lsort -real    -decreasing [array names hilf]] {
      set k $hilf($j)
      set Tabelle($i) $HTabelle($k)
      incr i
   }
                             
   return 0
}

#===========================================================
#
# Procedure: cn_rangliste
#
# Purpose: Erstellen der Rangliste
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Bis zu dieser Runde wird die Rangliste gebildet.
#
# Postconditions:       
#  Rangliste ist erstellt wordem, in Datei gespeichert und in
#  Fenster angezeigt worden.
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_rangliste { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Tabelle mglich."
      return
   }

   # Holen der selektierten Runde  
   set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Bilden der Rangliste
   set s [cn_rangliste_build $Tid $Runde Rangliste]

   # Sortieren der Rangliste
   set s [cn_rangliste_sort Rangliste]

   # Darstellen der Rangliste
   set s [ui_rangliste_display $Tname $Runde Rangliste]

   return 0

}

#===========================================================
#
# Procedure: cn_rangliste_build
#
# Purpose: Erstellen der Rangliste fuer eine bestimmte Runde
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Bis zu dieser Runde wird die Rangliste gebildet.
#
# Postconditions:       
#  Rangliste ist erstellt worden
#  Struktur der Rangliste:
#     Brettnr  Name   Verein-Nr  Punkte Spiele
#     Index = Verein-Nr*100 + Brettnr
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_rangliste_build { Tid Runde ArrayRangliste } {

   upvar $ArrayRangliste Rangliste

   # Laden aller Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]

   # Laden aller Spieler
   foreach k [array names mannschaften] {
      set Mid [lindex $mannschaften($k) 0]
      catch { unset Spieler }
      set s [db_spieler_load $Tid $Mid Spieler]
      foreach j [lsort -integer [array names Spieler]] {
         set wert [expr $k*100+$j]
         set Rangliste($wert) [list $j [lrange $Spieler($j) 1 end] \
                        [lindex $mannschaften($k) 1] 0.0 0]
      }
   }

   # Laden der Wettkmpfe
   for { set i 1 } { $i <= $Runde } { incr i } {
      set s [db_runde_load $Tid $i wettkampf]
      foreach j [lsort -integer [array names wettkampf]] {
         set s [db_wettkampf_load $Tid $i $j Brettergebnisse]
         if {$s} { 
            continue 
         }
         foreach k [lsort -integer [array names Brettergebnisse]] {
            set heim [lindex $Brettergebnisse($k) 0]
            set gast [lindex $Brettergebnisse($k) 1]
            set erg  [lindex $Brettergebnisse($k) 2]
            set hvereinnr [lindex $heim 0]
            set hbrettnr [lindex $heim 1]
            set hwert [expr 100*$hvereinnr+$hbrettnr]
            set hpunkte [lindex $Rangliste($hwert) 3]
            set hspiele [lindex $Rangliste($hwert) 4]
            set hname   [lindex $Rangliste($hwert) 1]
            set heimverein [lindex $Rangliste($hwert) 2]
            set gvereinnr [lindex $gast 0]
            set gbrettnr [lindex $gast 1]
            set gwert [expr 100*$gvereinnr+$gbrettnr]
            set gpunkte [lindex $Rangliste($gwert) 3]
            set gspiele [lindex $Rangliste($gwert) 4]
            set gname   [lindex $Rangliste($gwert) 1]
            set gastverein [lindex $Rangliste($gwert) 2]

            incr gspiele
            incr hspiele

            switch -- $erg {
               1-0 { set hpunkte [expr $hpunkte+1.0] }
               0-1 { set gpunkte [expr $gpunkte+1.0] }
               +/- { set hpunkte [expr $hpunkte+1.0]; set gspiele [expr $gspiele-1]; }
               -/+ { set gpunkte [expr $gpunkte+1.0]; set hspiele [expr $hspiele-1]; }
               1/2 { set hpunkte [expr $hpunkte+0.5]
                     set gpunkte [expr $gpunkte+0.5] }
            }
            set Rangliste($hwert) [list $hbrettnr $hname $heimverein $hpunkte $hspiele]
            set Rangliste($gwert) [list $gbrettnr $gname $gastverein $gpunkte $gspiele]
         }
      }
   }
   return 0
}

#===========================================================
#
# Procedure: cn_rangliste_sort
#
# Purpose: Sortieren der Rangliste
#
# Preconditions:
#  Ein gltiges Ranglisten-Array mu existieren.
#
# Postconditions:       
#  Rangliste ist fallend nach Brettpunkten sortiert worden.
#  Struktur der Rangliste:
#     Brettnr  Name   Verein-Nr  Punkte Spiele
#     Index = Verein-Nr*100 + Brettnr
#     Sortierkriterium = 
#       (Punkte*1000)+(AnzahlPartien)+.(index/10000)
#
#     nun: i1= (100-Brettnr)*100 + Verein-Nr
#               9900..5000       + 1..100   9999..5001
#       (Punkte*1000)+(AnzahlPartien)+.(i1/10000)
#        500..97000    99-  0..97
#          
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_rangliste_sort { ArrayRangliste } {
global tcl_precision
   set tcl_precision 17
          
   upvar $ArrayRangliste Rangliste
              
   # Bilden eines Hilfsarrays zum Sortieren
   # Schlssel: Punkte*1000 + Spiele
   foreach k [lsort -integer [array names Rangliste]] {
      set spiele [lindex $Rangliste($k) 4]
      set punkte [lindex $Rangliste($k) 3]
#-- BEGIN CHANGE 31-OCT-1996 ------------
      set vereinnr [expr $k/100]
      set brettnr  [expr $k-$vereinnr*100]
      set i1 [expr (100-$brettnr)*100+$vereinnr]
      set wert [expr 1000.0*$punkte+(99-$spiele)+$i1*1.0/10000]
#-- END CHANGE 31-OCT-1996 --------------
      set hilf($wert) $k
      set HRangliste($k) $Rangliste($k)
   }

   # Umsortieren des Hilfsfeldes und damit der Rangliste
   catch { unset Rangliste }
   set i 1
   foreach j [lsort -real  -decreasing [array names hilf]] {
      set k $hilf($j)
      set Rangliste($i) $HRangliste($k)
      incr i
   }
   return 0
}


