#===========================================================
#
# Procedure: cn_rundenbericht
#
# Purpose: Erstellen des Rundenberichts
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Bis zu dieser Runde wird der Rundenbericht erstellt.
#  Enthalten ist:
#     Spielleiter
#     Tabelle
#     Einzelergebnisse
#     Top Ten
#
# Postconditions:       
#  Rundenbericht ist erstellt wordem, in Datei gespeichert und in
#  Fenster angezeigt worden.
#
# Globals
#  num_rangliste
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Der Dateiname des Rundenberichtes wird im Window mit
#         angezeigt. Damit ist Bearbeitung mit einem anderen
#         Werkzeug mglich.
#
#-------------------------------------------------------
                                                                 
proc cn_rundenbericht { } {
   global num_rangliste

   # Holen Turnierdaten 
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Tabelle mglich."
      return
   }

   # Holen der selektierten Runde  
   set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Bilden der Rangliste
   set s [cn_rangliste_build $Tid $Runde Rangliste]

   # Sortieren der Rangliste
   set s [cn_rangliste_sort Rangliste]

   # Speichern der Rangliste (erste 10)
   set s [db_rangliste_store $Tid $num_rangliste Rangliste]

   # Erstellen der Tabelle
   set s [cn_mannschaft_punkte $Tid $Runde Tabelle]
   if {$s} {
      ui_warning $Tname "Tabelle nicht erstellt"
      return
   }

   # Tabelle sortieren
   set s [cn_tabelle_sort Tabelle]

   # Tabelle speichern
   set s [db_tabelle_store $Tid Tabelle]
                                                    
   # Erstellen der Wettkampfberichte
   set s [cn_wettkampfbericht_build $Tid $Runde Wettkampfbericht]

   # Speichern des Wettkampfberichtes
   set s [db_wettkampfbericht_store $Tid Wettkampfbericht]

   # Zusammenstellen des Rundenberichtes
   set s [cn_rundenbericht_build $Tid $Runde $Tname Spielleiter Rundenbericht]
          
   # Speichern des Rundenberichtes
   set s [db_rundenbericht_store $Tid $Runde Rundenbericht dateiname]

   # Anzeigen des Rundenberichtes
   set s [ui_rundenbericht_display $Tid $Rundenbericht $dateiname]

   return 0

}
#===========================================================
#
# Procedure: cn_wettkampfbericht_build
#
# Purpose: Erstellen des Wettkampfberichtes Rangliste fuer eine bestimmte Runde
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Bis zu dieser Runde wird der Wettkampfbericht gebildet.
#
# Postconditions:       
#  Wettkampfbericht ist erstellt worden
#  Struktur der Rangliste: keine, Abbildung sequentielle Datei
#
# Globals
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 27-MAY-1997
# Name: G.Niklaus
# Reason: Anzeigen kampfloser Wettkaempfe
#
#-------------------------------------------------------

proc cn_wettkampfbericht_build { Tid Runde ArrayWettkampfbericht } {

   upvar $ArrayWettkampfbericht Wettkampfbericht 
   set dashes "-------------------------------------------------------"

   # Laden aller Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]

   # Laden aller Spieler
   foreach k [lsort -integer [array names mannschaften]] {
      set Mid [lindex $mannschaften($k) 0]
      catch { unset Spieler }
      set s [db_spieler_load $Tid $Mid Spieler]
      foreach j [lsort -integer [array names Spieler]] {
         set wert [expr $k*100+$j]
         set AlleSpieler($wert)  [lrange $Spieler($j) 1 end]
      }
   }

   # Zeilenzhler
   set kk 0
   # Laden der Wettkmpfe
   set i  $Runde
   set s [db_runde_load $Tid $i wettkampf]
   foreach j [lsort -integer [array names wettkampf]] {
      set wettkampfflag [lindex $wettkampf($j) 2] 
      if { $wettkampfflag == 0 } { continue }

      set spielflag "  "
      if { $wettkampfflag == 2 } { set spielflag "kl" }

      # Als erstes: Mannschaftsergebnis
      incr kk
      set hmann [lindex $wettkampf($j) 0]
      set gmann [lindex $wettkampf($j) 1]

      set Wettkampfbericht($kk) [format "%-22s %3s - %3s %2s %19s" \
          [lindex $mannschaften($hmann) 1]  \
          [lindex $wettkampf($j) 3] \
          [lindex $wettkampf($j) 5] \
          $spielflag \
          [lindex $mannschaften($gmann) 1] ]
      set Wettkampfbericht([incr kk]) $dashes

      
      # Laden nur, wenn Wettkampf auch gespielt wurde
      if { $wettkampfflag == 1 } {
         set s [db_wettkampf_load $Tid $i $j Brettergebnisse]
         if {$s} { continue }    
                                  
         # Brettergebnisse des Wettkampfes sind verfgbar
         # Nun Auffuehren der Einzelergebnisse
         foreach k [lsort -integer [array names Brettergebnisse]] {
            set heim [lindex $Brettergebnisse($k) 0]
            set gast [lindex $Brettergebnisse($k) 1]
            set erg  [lindex $Brettergebnisse($k) 2]
   
            set hvereinnr [lindex $heim 0]
            set hbrettnr [lindex $heim 1]
            set hwert [expr $hvereinnr*100+$hbrettnr]
            set hname   $AlleSpieler($hwert)
   
            set gvereinnr [lindex $gast 0]
            set gbrettnr [lindex $gast 1]
            set gwert [expr 100*$gvereinnr+$gbrettnr]
            set gname   $AlleSpieler($gwert)
   
            set Wettkampfbericht([incr kk]) [format "%2s %-22s %3s %22s %2s" \
                $hbrettnr $hname $erg $gname $gbrettnr]
         }
      }
      set Wettkampfbericht([incr kk]) " "
   }
   return 0
}

#===========================================================
#
# Procedure: cn_rundenbericht_build
#
# Purpose: Erstellen des Rundenberichtes fuer eine bestimmte Runde
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Fuer diese Runde wird der Rundenbericht gebildet.
#
# Postconditions:       
#  Rundenbericht ist erstellt worden
#  Struktur: keine, Abbildung sequentielle Datei
#
# Globals
#  turdir                  
#  wett_bericht
#  toptenfile
#  tabellenfile
#
# Returns: 0 = success
#=============================================================
 
proc cn_rundenbericht_build { Tid Runde Tname ArraySpielleiter VarRundenbericht } {
global turdir
global wett_bericht
global toptenfile
global tabellenfile 
global datumcmd

   upvar $ArraySpielleiter Spielleiter 
   upvar $VarRundenbericht Rundenbericht 

   set datum [eval $datumcmd]

   set dashes "-----------------------------------------------------------"
   set Rundenbericht "$Tname ($Spielleiter(globaltid))\n"
   set Rundenbericht2 "$dashes\nRunde ..............: $Runde\nDatum der Erstellung: $datum\n\n"
   set Rundenbericht3 "$Spielleiter(Name)\n$Spielleiter(Strasse)\n$Spielleiter(Wohnort)\nTel.: $Spielleiter(Telefon)\nFAX:  $Spielleiter(FAX)\nMail: $Spielleiter(Mail)\n\n"

   set curdir [pwd]
   cd $turdir
   cd $Tid
                                                                                       
   set f1 [open $tabellenfile r]
   set Tabelle [read $f1]
   close $f1

   set f2 [open $wett_bericht r]
   set Wettkampfbericht [read $f2]
   close $f2

   set f3 [open $toptenfile r]
   set Rangliste [read $f3]
   close $f3

   append Rundenbericht $Rundenbericht2 $Rundenbericht3 $Tabelle $Wettkampfbericht $Rangliste

   return 0
}

