#===========================================================
#
# Procedure: cn_senden_email
#
# Purpose: Vorbereiten der Daten zum Senden durch eMail
#
# Preconditions:
#  Turnier muss geoeffnet sein
#  Runde muss selektiert sein
#
# Postconditions:       
#  Im Directory des Turnieres ist Datei index.htm und <turnier>.zip
#  angelegt worden.
#
# Globals
#          
# Returns: 0 = success
#=============================================================

proc cn_senden_email { } {

   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }                                    

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Tabelle mglich."
      return
   }

   # Holen der selektierten Runde
   set Runde "" ; set Rundendatum ""; set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {                              
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Anlegen der WWW-Seiten
   set s [db_create_www $Tid $Tname $Runde]
   if {$s} {
      ui_warning $Tname "WWW-Seiten konnten nicht angelegt werden."
      return   
   }

   # Zusammenzippen der WWW-relevanten Seiten fuers Mailen.
   set zipfile ""; set s [db_create_zip $Tid $Runde zipfile]
   if {$s} {
      ui_warning $Tname "ZIP-Datei konnte nicht angelegt werden."
      return
   } else  {
      ui_warning $Tname "ZIP-Datei $zipfile wurde angelegt und kann per eMail versandt werden."
      return
   }
}

#===========================================================
#
# Procedure: cn_senden_www
#
# Purpose: Vorbereiten der Daten zum Senden durch WWW/FTP
#
# Preconditions:
#  Turnier muss geoeffnet sein
#  Runde muss selektiert sein
#
# Postconditions:       
#  Im Directory des Turnieres ist Datei index.htm und <turnier>.zip
#  angelegt worden.
#
# Globals
#          
# Returns: 0 = success
#=============================================================

proc cn_senden_www { } {

   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }                                    

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Tabelle mglich."
      return
   }

   # Holen der selektierten Runde
   set Runde "" ; set Rundendatum ""; set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {                              
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Anlegen der WWW-Seiten
   set s [db_create_www $Tid $Tname $Runde]
   if {$s} {
      ui_warning $Tname "WWW-Seiten konnten nicht angelegt werden."
      return   
   }

   # Zusammenzippen der WWW-relevanten Seiten fuers Mailen.
   set zipfile ""; set s [db_create_zip $Tid $Runde zipfile]
   if {$s} {
      ui_warning $Tname "ZIP-Datei konnte nicht angelegt werden."
      return
   }

   # Schreiben der FTP-Informationen in die FTP-Datei.
   set s [db_create_ftp $Tid ftpfile]
   if {$s} {
      ui_warning $Tname "FTP-Datei $ftpfile konnte nicht angelegt werden."
      return
   } else {
      ui_warning $Tname "FTP-Datei $ftpfile ist angelegt worden."
      return
   }
}

#===========================================================
#
# Procedure: cn_turnier_import
#
# Purpose: Importieren der Daten eines Turnieres
#
# Preconditions:                          
#  Es darf kein Turnier geffnet sein.
#
# Postconditions:       
#  Die Daten eines Turnieres sind geladen worden. Ein davor vorhandenes
#  Turnier wurde mit den Daten berschrieben. Die Daten stehen als
#  ZIP-File im Export-Directory bereit.
#
# Globals
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed:  4-OCT-1997
# Name: G.Niklaus
# Reason: Creation
#
#-------------------------------------------------------
                                                                 
proc cn_turnier_import { } {

   # Holen Turnierdaten 
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {!$s} {
      ui_warning $Tname "Fr den Import darf kein Turnier geffnet."
      return
   }

   set Tid ""   
   # Auflisten der vorhandenen Turniere und Auswahl eines Turniers
   set s [ui_turnier_list Tid Tname import]

   return 0

}

