#===========================================================
#                                                 
# Procedure: Begegnung
#
# Purpose: Bestimmung einer Begegnung
#
# Preconditions:
#  Anzahl der Mannschaften, Nummer vo Wettkampf und Runde bekannt. 
#            
# Postconditions:
#  Zurueckgeliefert wird die Startnummer der Mannschaft!
#  Die Formel ist so!
#
# Returns: 0 = success
#          1 = failure
#=============================================================

proc Begegnung { Brett Runde TlnAnzahl } {

   set k [expr $TlnAnzahl/2*($Runde-1)]
   set k [expr $Brett+$k-1]
   set k [expr round(fmod($k,[expr $TlnAnzahl-1]))]
   set k [expr $k+1]
   return $k
}
                                 
#============================================================
#
# Procedure: db_turnier_get
#
# Purpose: Holen aller Daten des geffneten Turnieres
#
# Preconditions:
#   Variable turdir ist gesetzt und zeigt auf das Directory,
#   unter dem alle Turniere hngen. Ein Turnier mu geffnet sein!
#
# Postconditions:
#   Tid, Tname, Spielnum, Spielleiter sind geladen.
#
# Globals:
#              
# Returns:  0 = success
#           1 = Turnier kann nicht gelesen werden.
#
#=============================================================

proc db_turnier_get  { VarTid VarTname VarSpielnum ArraySpielleiter } {
   upvar $VarTid Tid
   upvar $VarTname Tname
   upvar $VarSpielnum Spielnum
   upvar $ArraySpielleiter Spielleiter

   set s [db_Tid_get Tname Tid ]
   if {$s} { return 1 } ;#  Fehler!

   set s [db_turnier_open $Tid Tname Spielnum Spielleiter]
   if {$s} { return 1}; # Fehler!

   if {!$s} {return 0 } else { return 1}

}

#============================================================
#
# Procedure: db_turnier_load
#
# Purpose: Laden der Turnierdaten
#
# Preconditions:
#   Variable turdir ist gesetzt und zeigt auf das Directory,
#   unter dem alle Turniere hngen. Tid muss einen gltigen
#   Wert enthalten.
#
# Postconditions:
#    Falls Turnier existiert, werden Spielleiter, Spielnum, 
#    Mannschaften und Runden geladen.
#
# Globals:
#     turdir
#              
# Returns:  0 = success
#           1 = Turnier kann nicht gelesen werden.
#
#=============================================================

proc db_turnier_load { Tid VarTname VarSpielnum ArraySpielleiter Arrayrunden 
                       Arraymannschaften } {
   # Globals
   global turdir

   upvar $VarTname Tname
   upvar $VarSpielnum Spielnum
   upvar $ArraySpielleiter Spielleiter
   upvar $Arrayrunden runden
   upvar $Arraymannschaften mannschaften                      

   set s [db_turnier_open $Tid Tname Spielnum Spielleiter]
   if {$s} { return 1 } ;#  Fehler!

   set s [db_runde_selall $Tid runden]
#   if {$s} { return 1}; # Fehler!

   set s [db_mannschaft_selall $Tid mannschaften]
#   if {$s} { return 1}; # Fehler!

   if {!$s} {return 0 } else { return 1}

}

#============================================================
#
# Procedure: db_turnier_open
#
# Purpose: ffnen eines Turnieres
#
# Preconditions:
#   Variable turdir ist gesetzt und zeigt auf das Directory,
#   unter dem alle Turniere hngen. Tid muss einen gltigen
#   Wert enthalten.
#
# Postconditions:
#    Falls Turnier existiert, werden Spielleiter, Spielnum,
#    Mannschaften und Runden geladen.
#    Globale Variable curtid wird auf das geffnete Turnier gesetzt.
#
# Globals:
#     turdir - Root der Turniere
#     turnierfile - Name des Turnierfiles
#     curtid - Aktuell geffnetes Turnier
#
# Returns:  0 = success
#           1 = Turnier kann nicht gelesen werden.
#
#=============================================================

proc db_turnier_open { Tid VarTname VarSpielnum ArraySpielleiter } {
   # Globals
   global turdir
   global curtid
   global turnierfile

   upvar $VarTname Tname
   upvar $VarSpielnum Spielnum
   upvar $ArraySpielleiter Spielleiter

   set curdir [pwd]
   cd $turdir
   cd $Tid
   set f [open $turnierfile r]
   set Tname [gets $f]
   set Spielnum [gets $f]
   set Spielleiter(Name) [gets $f]
   set Spielleiter(Strasse) [gets $f]
   set Spielleiter(Wohnort) [gets $f]
   set Spielleiter(Telefon) [gets $f]
   set Spielleiter(FAX) [gets $f]
   set Spielleiter(Mail) [gets $f]
   set Spielleiter(globaltid) [gets $f]
   close $f
   cd $curdir
   set curtid $Tid; # Turnier geffnet!
   return 0;
}

#============================================================
#
# Procedure: db_turnier_close
#
# Purpose: Schlieen eines geffneten Turnieres
#
# Preconditions:
#   Turnier mit der bergebenen Tid mu geffnet sein.
#
# Postconditions:
#    Turnier ist geschlossen. 
#    Globale Variable curtid wird auf 0 gesetzt.
#
# Globals:
#     curtid - Aktuell geffnetes Turnier
#              
# Returns:  0 = success
#           1 = Turnier kann nicht geschlossen werden.
#
#=============================================================

proc db_turnier_close { Tid } {
   # Globals
   global curtid

   set curtid 0; # Turnier geschlossen 
   return 0;
}

#============================================================
#
# Procedure: db_Tlist_get
#
# Purpose: Holen der Liste der vorhandenen Turniere
#
# Preconditions:
#   Variable turdir ist gesetzt und zeigt auf das Directory,
#   unter dem alle Turniere hngen. 
#   Variable listdircmd enthlt den Befehl zum Erstellen der
#   Directoryliste
#
# Postconditions:
#    Array Tlist enthlt als Index die Tids, als Inhalt den
#    Turniernamen.
#
# Globals:
#     turdir
#     listdircmd
#     turnierfile
#
# Returns:  0 = success
#           1 = Turnier kann nicht gelesen werden.
#
#=============================================================

proc db_Tlist_get { ArrayTlist } {
   # Globals
   global turdir
   global turnierfile
   global listdircmd

   upvar $ArrayTlist Tlist

   # Holen der vorhandenen Tids = Directories
   set curdir [pwd]
   cd $turdir
   set err [catch {eval $listdircmd } dirlist]
   if { $err == 0 } {
      set dirlist [lsort -integer -decreasing $dirlist]
      # Schleife ber alle Elemente
      foreach i $dirlist {
         cd $i
         set f [open $turnierfile r]
         set Tname [gets $f]
         close $f
         set Tlist($i) $Tname
         cd ..
      }
      cd $curdir
   }
   return 0
}               
   
#============================================================
#
# Procedure: db_Tid_getnext
#  
# Purpose: Holen der nchsten Turnierid Tid
#
# Preconditions:
#   Variable turdir ist gesetzt und zeigt auf das Directory,
#   unter dem alle Turniere hngen.
#
# Postconditions:
#    Falls Datei 'tid.txt' existiert, wird der Inhalt um 1
#    erhht und zurckgegeben. Falls die Datei nicht existierte,
#    ist sie nun angelegt, der Inhalt ist 1.
#
# Globals:
#     turdir
#     dirlistcmd
# Returns:  0 = success
#           1 = File kann nicht gelesen bzw. geschrieben werden.
#
#=============================================================

proc db_Tid_getnext { VarTid } {
   # Globale Variable
   global turdir
   global listdircmd
  
   upvar $VarTid Tid        

   # Holen der vorhandenen Tids = Directories
   set curdir [pwd]
   cd $turdir
   set err [catch {eval $listdircmd } dirlist]
   if { $err == 0 } {
      set dirlist [lsort -integer -decreasing $dirlist]
      set dir [lindex $dirlist 0]
      if { [string compare $dir ""] == 0 } { set Tid 1} else {
         set Tid [incr dir]
      }
   }
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_Mid_getnext
#  
# Purpose: Holen der nchsten Mannschaftsid Mid
#
# Preconditions:
#   Variable turdir ist gesetzt und zeigt auf das Directory,
#   unter dem alle Turniere hngen. Variable Tid enthlt die Turnierid.
#
# Postconditions:
#    Falls Datei $mannschfile existiert, werden die Datenstze gelesen
#    und der hchste Wert von Mid ermittelt. Dieser Wert wird um 1 
#    erhht und zurckgeliefert. 
#    Falls die Datei nicht existiert, wird der Wert 1 zurckgeliefert.
#
# Globals:
#     turdir
#     mannschfile
#
# Returns:  0 = success
#           1 = File kann nicht gelesen bzw. geschrieben werden.
#
#=============================================================

proc db_Mid_getnext { Tid VarMid } {
   # Globale Variable
   global turdir
   global mannschfile
  
   upvar $VarMid Mid        

   # Setzen auf Turnierdirectory
   set curdir [pwd]
   cd $turdir
   cd $Tid                        

   set s [catch {set f [open $mannschfile r]} ]
   if {$s} {
      cd $curdir; set Mid 1; return 0;
   }

   set zeile [gets $f]
   while { ![eof $f] } {
      lappend Mids [lindex $zeile 0]
      set zeile [gets $f]
   }
   close $f
   set Mid [lindex [lsort -integer -decreasing $Mids] 0]
   incr Mid
   cd $curdir
   return 0
}


