#============================================================
#
# Procedure: db_dir_create     
#
# Purpose: Anlegen eines neuen Directories
#
# Preconditions:
#    Rootdirectory mu existieren.
#    bergabeparameter Tid mu gltigen Directorynamen enthalten
#
# Postconditions:
#    Angegebene Directory ist angelegt.
#              
# Globals: makedir
#          turdir
#
# Returns: 0 = success
#          1 = Directory nicht angelegt
#
#=============================================================

proc db_dir_create { Tid } {
   # Globals
   global makedircmd
   global turdir
     
   set makedir [format $makedircmd $Tid]
   set curdir [pwd]
   cd $turdir
   eval $makedir
   set err [catch {cd $Tid}]
   cd $curdir
   return $err
}
   
#============================================================
#
# Procedure: db_Turnier_save
#
# Purpose: Abspeichern der allgemeinen Turnierdaten
#
# Preconditions: Tid mu auf ein gltiges Turnier zeigen.
#   Das Turnierdirectory mu vorhanden sein.
#
# Postconditions:
#   Turniername, Anzahl Spieler/Mannschaft und Spielleiterdaten
#   sind in Datei $turdir/$Tid/turnier.txt gespeichert.
#
# Globals:
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_Turnier_save { Tid Tname Spielnum ArraySpielleiter } {
   global turdir
   upvar $ArraySpielleiter Spielleiter

   set err [catch {set f [open $turdir/$Tid/turnier.txt w]}]
   if {!$err} {
      puts $f $Tname
      puts $f $Spielnum
      puts $f $Spielleiter(Name)
      puts $f $Spielleiter(Strasse)
      puts $f $Spielleiter(Wohnort)
      puts $f $Spielleiter(Telefon)
      puts $f $Spielleiter(FAX)
      puts $f $Spielleiter(Mail)

      puts $f $Spielleiter(globaltid)
      close $f
   }
   return $err
}

#============================================================
#
# Procedure: db_auslos_get
#
# Purpose: Pruefen, ob Turnier ausgelost ist.
#
# Preconditions: Turnier mu geffnet sein.
#   Es wird die Datei $auslosungfile geprft, ob vorhanden
#   oder Inhalt = 0
#
# Postconditions:
#   Turnier ist entweder ausgelost oder nicht.
#
# Globals:
#   turdir
#   auslosungfile
#
# Returns:  0 = ausgelost
#           1 = nicht ausgelost
#
#=============================================================

proc db_auslos_get { Tid } {
   # Globals
   global turdir             
   global auslosungfile

   set curdir [pwd]
   cd $turdir
   cd $Tid
  
   if { [file exists $auslosungfile] == 1 } {
      set f [open $auslosungfile r]
      gets $f zeile
      close $f
      if { [string compare $zeile "0"] == 0 } {
         cd $curdir
         return 1
      }
      cd $curdir
      return 0
   } else {
      cd $curdir
      return 1
   }                                           
}

#============================================================
#
# Procedure: db_auslos_set
#     
# Purpose: Setzen, da Turnier ausgelost/nicht ausgelost ist.
#
# Preconditions: Turnier mu geffnet sein.
#     Wert darf 0 (=storno) oder 1 (=ausgelost) sein.
#
# Postconditions:
#   Es wird die Datei $auslosungfile angelegt und mit dem 
#   Wert 1 beschrieben.
#
# Globals:
#   turdir
#   auslosungfile
#
# Returns:  0 = success
#
#=============================================================
#--------------------------------------------------------
# Changed:  5-MAY-1997
# Name: G.Niklaus
# Reason: Loeschen nicht benoetigter Files
#
#-------------------------------------------------------

proc db_auslos_set { Tid Wert } {
   # Globals
   global turdir             
   global auslosungfile
   global remofilcmd
   global mannschaftsergebnisfile
   global wettkampffile
   global rundenbericht

   set curdir [pwd]
   cd $turdir
   cd $Tid

   if {$Wert == 0 } {
      set s [db_auslos_del $Tid]
   } else {       
      set f [open $auslosungfile w]
      puts $f $Wert
      close $f
   }
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_auslos_del
#     
# Purpose: Loeschen der nicht bneoetigten Files
#
# Preconditions: Turnier mu geffnet sein.
#
# Postconditions:
#   Es sind die Dateien $auslosungfile, $mannschaftsergebnisfile,
#   $wettkampffile und $rundenbericht geloescht worden.
#
# Returns:  0 = success
#=============================================================
proc db_auslos_del { Tid } {
   # Globals
   global turdir             
   global auslosungfile
   global remofilcmd
   global mannschaftsergebnisfile
   global wettkampffile
   global rundenbericht

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set remofil [format $remofilcmd $auslosungfile]
   catch {eval $remofil}

   foreach k [glob -nocomplain $mannschaftsergebnisfile*.*] {
      set remofil [format $remofilcmd $k]
      catch {eval $remofil}
   }
   foreach k [glob -nocomplain $wettkampffile.*] {
      set remofil [format $remofilcmd $k]
      catch {eval $remofil}
   }
   foreach k [glob -nocomplain $rundenbericht*] {
      set remofil [format $remofilcmd $k]
      catch {eval $remofil}
   }
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_Tid_get
#
# Purpose: Holen von Turniernamen und Tid des aktuell
#          geffneten Turnieres.
#
# Preconditions: Turnier mu geffnet sein.
#   
#
# Postconditions:
#   Turniername, Tid werden geholt.
#
# Globals:
#   curtid
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_Tid_get { VarTname VarTid } {
   # Globals
   global curtid
   global turdir             

   upvar $VarTname Tname
   upvar $VarTid   Tid

   set Tname "Turnier"
   if { [string compare $curtid "0"]  != 0 } {
      set Tid $curtid
      return 0
   } 
   return 1
}

#============================================================
#
# Procedure: db_runde_selall
#
# Purpose: Holen der Rundendaten des Turnieres
#
# Preconditions: Turnier mu geffnet sein.
#   
# Postconditions:
#   Rundendaten in Array geholt.
#
# Globals:
#   rundenfile : Name des Rundenfiles
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_runde_selall { Tid Varrunden } {
   # Globals                     
   global turdir; # Directory der Turniere
   global rundenfile
       
   upvar $Varrunden runden

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set s [catch {set f [open $rundenfile r]} ]
   if {$s} {cd $curdir; return 1}

   set i 0
   set zeile [gets $f]
   while { ![eof $f] } {
      incr i       
      set runden($i) $zeile
      set zeile [gets $f]
   }
   close $f
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_runde_modify
#
# Purpose: ndern des Spieldatums einer Runde
#
# Preconditions: Tid mu ein gltiges Turnier enthalten
#   Runde mu auf eine bekannte Runde zeigen.
#
# Postconditions:
#   Die angegebene Runde ist durch das Rundendatum berschrieben.
#
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_runde_modify { Tid Runde Rundendatum } {

   # Holen der bekannten Runden
   set s [db_runde_selall $Tid runden]
   if {$s} { return 1}

   # ndern der Runde
   set runden($Runde) $Rundendatum

   # Speichern der neuen Daten
   set s [db_runde_store $Tid runden]
   if {$s} {return 1}
   return 0
}                      

#============================================================
#
# Procedure: db_runde_add
#
# Purpose: Hinzufgen einer neuen Runde
#              
# Preconditions: Turnier mu geffnet sein.
#
# Postconditions:
#   Die Runden werden gelesen, gendert und neu in Datei geschrieben
#
# Globals:
#   curtid
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler    
#=============================================================

proc db_runde_add { Tid Rundendatum } {
   # Globals 
   global turdir

   set s [db_runde_selall $Tid runden]
   if { [info exists runden] } {
      set i [lindex [lsort -integer -decreasing [array names runden] ] 0 ]
      incr i
   } else {
      set i 1
   }
   set runden($i) $Rundendatum
   set s [db_runde_store $Tid runden]
   return $s
}

#============================================================
#
# Procedure: db_runde_store 
#
# Purpose: Speichern der Rundendaten
#
# Preconditions: Turnier mu geffnet sein.
#     
#
# Postconditions:
#   Rundenspieltermine sind in Datei $turdir/$Tid/runden.txt geschrieben.
#
# Globals:
#   rundenfile
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_runde_store { Tid Arrayrunden } {
   # Globals
   global turdir
   global rundenfile

   upvar $Arrayrunden runden

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set f [open $rundenfile w]
   set ilist [lsort -integer [array names runden] ]
   foreach i $ilist {
      puts $f $runden($i)
   }
   close $f
   cd $curdir
   return 0
}



