#============================================================
#
# Procedure: db_wettkampfbericht_store
#              
# Purpose: Speichern des Wettkampfberichtes
#
# Preconditions:
#  Tid mu gltigen Wert haben, Wettkampfbericht mu gefllt sein.
# 
# Postconditions:
#  Wettkampfbericht ist gespeichert
# 
# Globals:
#   turdir                        
#   wett_bericht
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_wettkampfbericht_store { Tid ArrayWettkampfbericht } {
   # Globals
   global turdir
   global wett_bericht

   upvar $ArrayWettkampfbericht Wettkampfbericht 

   set curdir [pwd]
   cd $turdir
   cd $Tid
                      
   set f1 [open $wett_bericht w]
   foreach k [lsort -integer [array names Wettkampfbericht]] {
      puts $f1 $Wettkampfbericht($k)
   }
   close $f1
   cd $curdir         
   return 0
}

#============================================================
#
# Procedure: db_rundenbericht_store
#
# Purpose: Speichern des Rundenberichtes
#
# Preconditions:
#  Tid mu gltigen Wert haben, Rundenbericht mu gefllt sein.
# 
# Postconditions:
#  Rundenbericht ist gespeichert
# 
# Globals:
#   turdir
#   rund_bericht
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Rckgabe des Dateinamens des Rundenberichtes
#         Anhngen des Rundenberich-Anhanges
#-------------------------------------------------------
proc db_rundenbericht_store { Tid Runde VarRundenbericht Vardateiname } {
   # Globals
   global turdir
   global rundenbericht
   
   upvar $VarRundenbericht Rundenbericht 
   upvar $Vardateiname dateiname
         
   set dateiname $turdir/$Tid/$rundenbericht$Runde;

   set curdir [pwd]
   cd $turdir
   cd $Tid
                      
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Anhngen des Rundenbericht-Anhanges
#-------------------------------------------------------
   set s [db_rundenbericht_anhang_selall  $Tid $Runde Runden_Anhang Dateiname]

   append Rundenbericht $Runden_Anhang
#   puts $f1 ""
#   puts $f1 $Runden_Anhang

   set f1 [open $rundenbericht$Runde w]
   puts $f1 $Rundenbericht

   close $f1
   cd $curdir         
   return 0
}

#===========================================================
# E4: Sonstige, Bibliotheksfunktionen
#===========================================================

# Allgemeine Prozeduren
# XFNoParsing
# Program: template
# Description: yes no box
#                                   
# $Header: YesNoBox.t[2.3] Wed Mar 10 12:03:47 1993 garfield@garfield frozen $

global yesNoBox
set yesNoBox(activeBackground) ""
set yesNoBox(activeForeground) ""
set yesNoBox(anchor) n
set yesNoBox(background) ""
set yesNoBox(font) "*times-bold-r-normal*24*"
set yesNoBox(foreground) ""              
set yesNoBox(justify) center
set yesNoBox(afterYes) 0
set yesNoBox(afterNo) 0
set yesNoBox(button) 0

proc YesNoBox {{yesNoBoxMessage {Yes/no message}} {yesNoBoxGeometry 350x150}} {# xf ignore me 5
##########
# Procedure: YesNoBox
# Description: show yesno box
# Arguments: {yesNoBoxMessage} - the text to display
#            {yesNoBoxGeometry} - the geometry for the window
# Returns: none
# Sideeffects: none
##########
#
# global yesNoBox(activeBackground) - active background color
# global yesNoBox(activeForeground) - active foreground color
# global yesNoBox(anchor) - anchor for message box
# global yesNoBox(background) - background color
# global yesNoBox(font) - message font
# global yesNoBox(foreground) - foreground color
# global yesNoBox(justify) - justify for message box
# global yesNoBox(afterNo) - destroy yes-no box after n seconds.
#                            The no button is activated
# global yesNoBox(afterYes) - destroy yes-no box after n seconds.
#                             The yes button is activated

  global yesNoBox

  set tmpButtonOpt ""
  set tmpFrameOpt ""
  set tmpMessageOpt ""
  if {"$yesNoBox(activeBackground)" != ""} {
    append tmpButtonOpt "-activebackground \"$yesNoBox(activeBackground)\" "
  }
  if {"$yesNoBox(activeForeground)" != ""} {
    append tmpButtonOpt "-activeforeground \"$yesNoBox(activeForeground)\" "
  }
  if {"$yesNoBox(background)" != ""} {
    append tmpButtonOpt "-background \"$yesNoBox(background)\" "
    append tmpFrameOpt "-background \"$yesNoBox(background)\" "
    append tmpMessageOpt "-background \"$yesNoBox(background)\" "
  }
  if {"$yesNoBox(font)" != ""} {
    append tmpButtonOpt "-font \"$yesNoBox(font)\" "
    append tmpMessageOpt "-font \"$yesNoBox(font)\" "
  }
  if {"$yesNoBox(foreground)" != ""} {
    append tmpButtonOpt "-foreground \"$yesNoBox(foreground)\" "
    append tmpMessageOpt "-foreground \"$yesNoBox(foreground)\" "
  }

  # start build of toplevel
  if {"[info commands XFDestroy]" != ""} {
    catch {XFDestroy .yesNoBox}
  } {
    catch {destroy .yesNoBox}
  }
  toplevel .yesNoBox \
    -borderwidth 0
  catch ".yesNoBox config $tmpFrameOpt"
  if {[catch "wm geometry .yesNoBox $yesNoBoxGeometry"]} {
    wm geometry .yesNoBox 350x150
  }
  wm title .yesNoBox {Alert box}
  wm maxsize .yesNoBox 1000 1000
  wm minsize .yesNoBox 100 100
  # end build of toplevel

  message .yesNoBox.message1 \
    -anchor "$yesNoBox(anchor)" \
    -justify "$yesNoBox(justify)" \
    -relief raised \
    -text "$yesNoBoxMessage"
  catch ".yesNoBox.message1 config $tmpMessageOpt"

  set xfTmpWidth \
    [string range $yesNoBoxGeometry 0 [expr [string first x $yesNoBoxGeometry]-1]]
  if {"$xfTmpWidth" != ""} {
    # set message size
    catch ".yesNoBox.message1 configure \
      -width [expr $xfTmpWidth-10]"
  } {
    .yesNoBox.message1 configure \
      -aspect 1500
  }

  frame .yesNoBox.frame1 \
    -borderwidth 0 \
    -relief raised
  catch ".yesNoBox.frame1 config $tmpFrameOpt"

  button .yesNoBox.frame1.button0 \
    -text "Ja" \
    -command "
      global yesNoBox
      set yesNoBox(button) 1
      if {\"\[info commands XFDestroy\]\" != \"\"} {
        catch {XFDestroy .yesNoBox}
      } {
        catch {destroy .yesNoBox}
      }"
  catch ".yesNoBox.frame1.button0 config $tmpButtonOpt"

  button .yesNoBox.frame1.button1 \
    -text "Nein" \
    -command "
      global yesNoBox
      set yesNoBox(button) 0
      if {\"\[info commands XFDestroy\]\" != \"\"} {
        catch {XFDestroy .yesNoBox}
      } {
        catch {destroy .yesNoBox}
      }"
  catch ".yesNoBox.frame1.button1 config $tmpButtonOpt"

  pack append .yesNoBox.frame1 \
              .yesNoBox.frame1.button0 {left fillx expand} \
              .yesNoBox.frame1.button1 {left fillx expand}

  # packing
  pack append .yesNoBox \
              .yesNoBox.frame1 {bottom fill} \
              .yesNoBox.message1 {top fill expand}

  if {$yesNoBox(afterYes) != 0} {
    after [expr $yesNoBox(afterYes)*1000] \
      "catch \".yesNoBox.frame1.button0 invoke\""
  }
  if {$yesNoBox(afterNo) != 0} {
    after [expr $yesNoBox(afterNo)*1000] \
      "catch \".yesNoBox.frame1.button1 invoke\""
  }

  # wait for the box to be destroyed
  update idletask
  grab .yesNoBox
  tkwait window .yesNoBox

  return $yesNoBox(button)
}

# XFNoParsing
# Program: template
# Description: alert box
#
# $Header: AlertBox.t[2.3] Wed Mar 10 12:02:31 1993 garfield@garfield frozen $

global alertBox
set alertBox(activeBackground) ""
set alertBox(activeForeground) ""
set alertBox(after) 0
set alertBox(anchor) nw
set alertBox(background) ""
set alertBox(font) ""
set alertBox(foreground) ""
set alertBox(justify) center
set alertBox(toplevelName) .alertBox
set alertBox(button) 0

proc AlertBox {{alertBoxMessage {Alert message}} {alertBoxCommand ""} {alertBoxGeometry 350x150} {alertBoxTitle "Alert box"} args} {# xf ignore me 5
##########
# Procedure: AlertBox
# Description: show alert box
# Arguments: {alertBoxMessage} - the text to display
#            {alertBoxCommand} - the command to call after ok
#            {alertBoxGeometry} - the geometry for the window
#            {alertBoxTitle} - the title for the window
#            {args} - labels of buttons
# Returns: The number of the selected button, ot nothing
# Sideeffects: none
# Notes: there exist also functions called:
#          AlertBoxFile - to open and read a file automatically
#          AlertBoxFd - to read from an already opened filedescriptor
##########
#
# global alertBox(activeBackground) - active background color
# global alertBox(activeForeground) - active foreground color
# global alertBox(after) - destroy alert box after n seconds
# global alertBox(anchor) - anchor for message box
# global alertBox(background) - background color
# global alertBox(font) - message font
# global alertBox(foreground) - foreground color
# global alertBox(justify) - justify for message box
# global alertBox(toplevelName) - the toplevel name

  global alertBox

  # show alert box
  if {[llength $args] > 0} {
    eval AlertBoxInternal "\{$alertBoxMessage\}" "\{$alertBoxCommand\}" "\{$alertBoxGeometry\}" "\{$alertBoxTitle\}" $args
  } {
    AlertBoxInternal $alertBoxMessage $alertBoxCommand $alertBoxGeometry $alertBoxTitle
  }

  if {[llength $args] > 0} {
    # wait for the box to be destroyed
    update idletask
    grab $alertBox(toplevelName)
    tkwait window $alertBox(toplevelName)

    return $alertBox(button)
  }
}

##########
# Procedure: AlertBoxInternal
# Description: show alert box internal
# Arguments: alertBoxMessage - the text to display
#            alertBoxCommand - the command to call after ok
#            alertBoxGeometry - the geometry for the window
#            alertBoxTitle - the title for the window
#            args - labels of buttons
# Returns: none
# Sideeffects: none
##########
proc AlertBoxInternal {alertBoxMessage alertBoxCommand alertBoxGeometry alertBoxTitle args} {# xf ignore me 6
  global alertBox

  set tmpButtonOpt ""
  set tmpFrameOpt ""
  set tmpMessageOpt ""
  if {"$alertBox(activeBackground)" != ""} {
    append tmpButtonOpt "-activebackground \"$alertBox(activeBackground)\" "
  }
  if {"$alertBox(activeForeground)" != ""} {
    append tmpButtonOpt "-activeforeground \"$alertBox(activeForeground)\" "
  }
  if {"$alertBox(background)" != ""} {
    append tmpButtonOpt "-background \"$alertBox(background)\" "
    append tmpFrameOpt "-background \"$alertBox(background)\" "
    append tmpMessageOpt "-background \"$alertBox(background)\" "
  }
  if {"$alertBox(font)" != ""} {
    append tmpButtonOpt "-font \"$alertBox(font)\" "
    append tmpMessageOpt "-font \"$alertBox(font)\" "
  }
  if {"$alertBox(foreground)" != ""} {
    append tmpButtonOpt "-foreground \"$alertBox(foreground)\" "
    append tmpMessageOpt "-foreground \"$alertBox(foreground)\" "
  }

  # start build of toplevel
  if {"[info commands XFDestroy]" != ""} {
    catch {XFDestroy $alertBox(toplevelName)}
  } {
    catch {destroy $alertBox(toplevelName)}
  }
  toplevel $alertBox(toplevelName) \
    -borderwidth 0
  catch "$alertBox(toplevelName) config $tmpFrameOpt"
  if {[catch "wm geometry $alertBox(toplevelName) $alertBoxGeometry"]} {
    wm geometry $alertBox(toplevelName) 350x150
  }
  wm title $alertBox(toplevelName) $alertBoxTitle
  wm maxsize $alertBox(toplevelName) 1000 1000
  wm minsize $alertBox(toplevelName) 100 100
  # end build of toplevel

  message $alertBox(toplevelName).message1 \
    -anchor "$alertBox(anchor)" \
    -justify "$alertBox(justify)" \
    -relief raised \
    -text "$alertBoxMessage"
  catch "$alertBox(toplevelName).message1 config $tmpMessageOpt"

  set xfTmpWidth \
    [string range $alertBoxGeometry 0 [expr [string first x $alertBoxGeometry]-1]]
  if {"$xfTmpWidth" != ""} {
    # set message size
    catch "$alertBox(toplevelName).message1 configure \
      -width [expr $xfTmpWidth-10]"
  } {
    $alertBox(toplevelName).message1 configure \
      -aspect 1500
  }

  frame $alertBox(toplevelName).frame1 \
    -borderwidth 0 \
    -relief raised
  catch "$alertBox(toplevelName).frame1 config $tmpFrameOpt"

  set alertBoxCounter 0
  set buttonNum [llength $args]
  if {$buttonNum > 0} {
    while {$alertBoxCounter < $buttonNum} {
      button $alertBox(toplevelName).frame1.button$alertBoxCounter \
        -text "[lindex $args $alertBoxCounter]" \
        -command "
          global alertBox
          set alertBox(button) $alertBoxCounter
          if {\"\[info commands XFDestroy\]\" != \"\"} {
            catch {XFDestroy $alertBox(toplevelName)}
          } {
            catch {destroy $alertBox(toplevelName)}
          }"
      catch "$alertBox(toplevelName).frame1.button$alertBoxCounter config $tmpButtonOpt"

      pack append $alertBox(toplevelName).frame1 \
                  $alertBox(toplevelName).frame1.button$alertBoxCounter {left fillx expand}

      incr alertBoxCounter
    }
  } {
    button $alertBox(toplevelName).frame1.button0 \
      -text "OK" \
      -command "
        global alertBox
        set alertBox(button) 0
        if {\"\[info commands XFDestroy\]\" != \"\"} {
          catch {XFDestroy $alertBox(toplevelName)}
        } {
          catch {destroy $alertBox(toplevelName)}
        }
        $alertBoxCommand"
    catch "$alertBox(toplevelName).frame1.button0 config $tmpButtonOpt"

    pack append $alertBox(toplevelName).frame1 \
                $alertBox(toplevelName).frame1.button0 {left fillx expand}
  }

  # packing
  pack append $alertBox(toplevelName) \
              $alertBox(toplevelName).frame1 {bottom fill} \
              $alertBox(toplevelName).message1 {top fill expand}

  if {$alertBox(after) != 0} {
    after [expr $alertBox(after)*1000] \
      "catch \"$alertBox(toplevelName).frame1.button0 invoke\""
  }
}

# eof



