#============================================================
#
# Procedure: db_mannschaftname_selall
#              
# Purpose: Laden der Mannschaftsnamen aus Datei
#
# Preconditions:
#  Tid muss gueltigen Wert besitzen
# 
# Postconditions:
#  Namen der Mannschaften des Turniers Tid werden in Array zurueckgeliefert
# 
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_mannschaftname_selall { Tid Varmannschaftname } {
   upvar $Varmannschaftname mannschaftname 

   set s [db_mannschaft_selall $Tid mannschaften]

   foreach k [lsort -integer [array names mannschaften]] {
      set mannschaftname($k) [lindex $mannschaften($k) 1]
   }
   return 0
}
#===========================================================
#
# Procedure: db_create_zip
#
# Purpose: Anlegen des ZIP-Files
#
# Preconditions:
#  Turnier muss gueltig sein
#  Runde muss gueltig sein
#
# Postconditions:       
#  Im Directory des Turnieres ist Datei <turnier>.zip
#  angelegt worden.
#
# Globals           
#
# Returns: 0 = success
#=============================================================
                            
proc db_create_zip { Tid Runde Varzipfile } {
   global turdir
   global zip
   global indexfile
   global datumcmd
   global spielplanfile
   global rundenbericht

   upvar $Varzipfile zipfile

   set curdir [pwd]
   cd $turdir
   cd $Tid
   
   set datum [eval $datumcmd]

   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   set zipname $Spielleiter(globaltid)
   set zipfile $turdir/$Tid/$zipname.zip

   # Holen der Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]

   foreach k [array names mannschaften] {
      lappend mids [lindex $mannschaften($k) 0]
   }

   catch {eval exec rm $zipname.zip}
   eval $zip $zipname.zip [glob $rundenbericht*] $indexfile $spielplanfile $mids

   cd $curdir
   return 0
}

#===========================================================
#      
# Procedure: db_create_www
#
# Purpose: Anlegen der WWW-Seiten
#
# Preconditions:
#  Turnier muss gueltig sein
#  Runde muss gueltig sein
#
# Postconditions:       
#  Im Directory des Turnieres ist Datei index.htm 
#  angelegt worden.
#
# Globals           
#   turdir                               
#   zip
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 31-AUG-1998
# Name: G.Niklaus
# Reason: Change of Layout of Webpages
#
#-------------------------------------------------------
                            
proc db_create_www { Tid Tname Runde } {
   global turdir
   global zip
   global indexfile
   global page_bgcolor
   global logo1
   global logo2
   global alt_logo1
   global alt_logo2
   global datumcmd
   global spielplanfile
   global rundenbericht
   global bg_image

   set curdir [pwd]
   cd $turdir
   cd $Tid
       
   set datum [eval $datumcmd]

   set s [db_turnier_get Tid Tname Spielnum Spielleiter]

   # Holen der Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]
   set s [db_runde_selall $Tid runden]

   set f1 [open $indexfile w]

   # HTML-Kopf schreiben
   puts $f1 "<HTML><HEAD><TITLE> $Tname</TITLE>"
   puts $f1 "<META NAME=\"GENERATOR\" CONTENT=\"TCL/TK TKTUR\">"
   puts $f1 "</HEAD>"

   # Der Seitenkopf
   puts $f1 "<BODY BACKGROUND=\"$bg_image\">"
   puts $f1 "<H1>$Tname</H1>"
                                         
   # Angaben zum Spielleiter
   puts $f1 "<P><FONT SIZE=+1><B>Spielleiter:<BR></B>"
   puts $f1 "$Spielleiter(Name)<BR>$Spielleiter(Strasse)<BR>$Spielleiter(Wohnort)<BR>"
   puts $f1 "Telefon: $Spielleiter(Telefon)<BR>FAX: $Spielleiter(FAX)<BR>Mail: $Spielleiter(Mail)<BR>"

   # Der allgemeine Teil
   puts $f1 "<HR> Der <A HREF=\"$spielplanfile\">Spielplan</A></FONT></P>"
   puts $f1 "<P><FONT SIZE=+1>Der derzeitige Stand des Turnieres als <A HREF=\"$Spielleiter(globaltid).zip\">"
   puts $f1 "Zip-Datei (40 kB)</A>.</FONT></P>"
#   puts $f1 "<HR>"

   puts $f1 "<P>"
   puts $f1 "<HR SIZE=3 NOSHADE WIDTH=\"100%\"></P>"

   # Die Turnierinformationen - Mannschaften
   puts $f1 "<TABLE BORDER=1 CELLPADDING=5 ><TR>"
   puts $f1 "<TD><B>Teilnehmende Mannschaften</B></TD>"
#   puts $f1 "<TH>Mailadresse</TH>"
   puts $f1 "<TD><B>Runden + Termine</B></TD></TR>"
   puts $f1 "<TR><TD><OL>"
   foreach k [lsort -integer [array names mannschaften]] {
      set mannschaftname [lindex $mannschaften($k) 1]
      set Mid [lindex $mannschaften($k) 0]
      puts $f1 "<LI><A HREF=\"$Mid\">$mannschaftname</A></LI>"
   } 
   puts $f1 "</OL></TD>"
                 
   # Die Turnierinformationen - Termine
   puts $f1 "<TD valign=top>"
   foreach k [lsort -integer [array names runden]] {
      set html_string($k) "$k: $runden($k)<BR>"
   }
   for { set k 0 } { $k < $Runde } { incr k } {
      set j [expr $k+1]
      set html_string($j) "$j: <A HREF=\"$rundenbericht$j\">$runden($j)</A><BR>"
   }
   foreach k [lsort -integer [array names html_string]] {
      puts $f1 $html_string($k)
   }
   puts $f1 "</TD></TR></TABLE>"

   # Der Seiten-Trailer
   puts $f1 "<div align=\"right\">"
   puts $f1 "<p align=\"right\"><em><FONT SIZE=-2>&copy; Schachkreis Mittelfranken-Nord<BR>"
   puts $f1 "Letzte &Auml;nderung: $datum<BR><SCRIPT language=\"JavaScript\">"
   puts $f1 "<!--"
   puts $f1 "document.write(\"URL: \"+document.location.href);"
   puts $f1 "//-->"
   puts $f1 "</SCRIPT>"
   puts $f1 "<BR>$Spielleiter(Name)</FONT></I></em>"
   puts $f1 "</div>"
   puts $f1 "</BODY>"
   puts $f1 "</HTML>"

   close $f1
   cd $curdir
   return 0
}

#===========================================================
#
# Procedure: db_create_ftp
#
# Purpose: Anlegen des FTP-Files
#
# Preconditions:
#  Turnier muss gueltig sein
#  Runde muss gueltig sein
#
# Postconditions:       
#  Im Directory des Turnieres ist Datei <turnier>.ftp
#  angelegt worden.
#
# Globals           
#
# Returns: 0 = success
#=============================================================
                            
proc db_create_ftp { Tid Varftpfile } {
   global turdir
   global zip
   global indexfile
   global datumcmd
   global spielplanfile
   global rundenbericht
   global wwwpath

   upvar $Varftpfile ftpfile

   set curdir [pwd]
   cd $turdir
   cd $Tid
   
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   set ftpname $Spielleiter(globaltid)
   set ftpfile $turdir/$Tid/$ftpname.ftp
   set zipname $Spielleiter(globaltid)
   
   # Holen der Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]

   foreach k [array names mannschaften] {
      lappend mids [lindex $mannschaften($k) 0]
   }

   catch {eval exec rm $ftpname.ftp}

   # Schreiben der FTP-Befehle in Datei
   set f1 [open $ftpname.ftp w]
   puts $f1 "lcd $turdir/$Tid"
   puts $f1 "cd ~/$wwwpath/$ftpname"
   puts $f1 "bin"
   puts $f1 "put $zipname.zip"
   puts $f1 "ascii"
   puts $f1 "put $indexfile"
   puts $f1 "put $spielplanfile"
   foreach k [glob $rundenbericht*] { puts $f1 "put $k" }
   foreach k $mids { puts $f1 "put $k" }
   puts $f1 "bye"
   puts $f1 ""

   close $f1
   
   cd $curdir
   return 0
}

