#===========================================================
# E2: UI Funktionen
#===========================================================

#============================================================
#
# Procedure: ui_turnier_list
#
# Purpose: Auflisten der vorhandenen Turniere
#  
# Preconditions: 
#  Globale Variable turdir mu gesetzt sein.
#  Directory mu existieren und darin sind die Directories der
#  vorhandenen Turnieren. Falls der Parameter 'func' ungleich 'display'
#  ist, wird ein lokaler Grab aufgesetzt und die Auswahlroutine gerufen,
#  um ein Turnier auszuwhlen. Dieses Turnier wird zurckgeliefert.
#
# Postconditions:
#  Alle vorhandenen Turniere werden in einem Popup Window angezeigt.
#  Ist der Parameter 'func' nicht gleich 'select', bleibt das Window
#  am Bildschirm erhalten.
#
# func kann sein: select, display, delete, export
#
# Globals:  turdir  - Directory der Turniere.
#           turwidth - Groesse der Listbox der Turniere
#
# Returns: 0 : Success
#          1 : Fehler
#
#=============================================================

proc ui_turnier_list { VarTid  VarTname func } {
   # Globals
   global turdir
   global lretval
   global turwidth 
   global lTid
   global lTname
   global geom52
   global listboxfont

   upvar $VarTid Tid
   upvar $VarTname Tname

   if { [string compare $func select] == 0 } {
      set Titel "Auswhlen eines Turniers"
      set Text "Bitte ein Turnier auswhlen"
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Einfgen der Export-Funktion
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  4-OCT-1997
# Name: G.Niklaus
# Reason: Einfgen der Importfunktion
#-------------------------------------------------------
   } elseif { [string compare $func export] == 0 } {
      set Titel "Exportieren eines Turniers"
      set Text "Bitte ein Turnier auswhlen"
   } elseif { [string compare $func import] == 0 } {
      set Titel "Importieren eines Turniers"
      set Text "Bitte ein Turnier auswhlen. Die Daten werden berschrieben!!"
   } elseif { [string compare $func delete] == 0} {
      set Titel "Lschen eines Turniers"
      set Text "Bitte zu lschendes Turnier auswhlen"
   } else {
      set Titel "Turnierliste"
      set Text "Liste der vorhandenen Turniere"
   }

   # Aufbau des UIs
   set r .ui_turnier_list
   catch {destroy $r}
   toplevel $r
   wm title $r "$Titel"
   wm minsize $r 1 1
   message $r.msg -text $Text -aspect 500

   frame $r.frame -bd 3
   pack $r.msg -side top -fill x
   pack $r.frame -side top -expand yes -fill both


   label $r.frame.text -text {Turnierliste}
   scrollbar $r.frame.scrollbar -orient vertical \
             -command "$r.frame.listbox yview"
   set befehl1 "listbox $r.frame.listbox -relief groove -font $listboxfont"
   set befehl2 "-yscrollcommand {$r.frame.scrollbar set} $geom52"
   eval [concat $befehl1 $befehl2]
           
   pack $r.frame.text -side top -fill x
   pack $r.frame.scrollbar -side left -fill y
   pack $r.frame.listbox   -side left -fill both -expand yes


   # Holen der bekannten Turniere
   set s [db_Tlist_get Tlist ]
   if {!$s} {
      if { [array size Tlist] > 0 } {
         foreach i [lsort -integer -decreasing [array names Tlist] ] {
            set temp [format "%4s %20s" $i $Tlist($i)]
            $r.frame.listbox insert end $temp
         }            
      }
   }                           
      
   # Code, wenn Turnier selektiert werden soll.
   if { [ string compare $func display ] != 0 } {
      set lTid 0
      button $r.ok -text OK -command "ui_turnier_getsel lTid lTname;destroy $r"
      button $r.cancel -text Abbrechen -command "destroy $r"
      pack $r.ok -side left -fill x -expand yes
      pack $r.cancel -side right -fill x -expand yes
      bind $r.frame.listbox <Double-Button-1> "ui_turnier_getsel lTid lTname;destroy $r"
                                                           
      # Lokaler Grab, wird aufgehoben durch ndern der Variable lretval
      update idletask
      grab $r
      tkwait window $r


      # Prfen der Aktion, Holen der Selektion, Lschen des Windows 
      # und verlassen der Prozedur.
      # 0 = Success, 1 = Fehler
      if { $lTid == 0 } { 
         return 1
      }  else {
         set Tid $lTid
         set Tname $lTname
         if { [ string compare $func export ] == 0 } {
            set s [ ui_turnier_export $Tid ]
         } elseif { [ string compare $func import ] == 0 } {
            set s [ ui_turnier_import $Tid ]
         }            
      }
   }                            
   return 0; # Success, bei Display!
}

#============================================================
#
# Procedure: ui_turnier_getsel
#
# Purpose: Holen der Selektion, zurckliefern des Wertes!
#
# Preconditions: 
#  Window .ui_turnier_list mu existieren
#  Selektion mu im dortiger Listbox .ui_turnier_list.frame.listbox 
#  enthalten sein.
#
# Postconditions:
#  Wert der Selektion wird geholt, die Tid herausgeholt und zurckgeliefert.
#
# Globals:  .ui_turnier_list.frame.listbox - Listbox, in der die 
#           Selektion ist.
#
# Returns: 0 : Success
#          1 : Fehler
#          Tid - selektiertes Turnier
#          Tname - Name des selektierten Turniers
#
#=============================================================
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Bug fixing - Prfen der Selection
#
#-------------------------------------------------------

proc ui_turnier_getsel { VarTid VarTname } {
   # Globals
   set r .ui_turnier_list

   # Referenzierte Variable
   upvar $VarTid Tid
   upvar $VarTname Tname
                        
   set selected_object [selection own]
   set err [ catch { set selected_row [selection get] } ]
   if { $err == 0 } {
      set selected_turnier [string trim $selected_row \{\} ]
      if { [string compare $selected_object "$r.frame.listbox"] == 0 } {
         set Tid [string trim [lindex $selected_turnier 0] ]
         set Tname [lrange $selected_turnier 1 end]
         return 0  
      }
   } 
   return 1 
}

#============================================================
#
# Procedure: ui_turnier_enter
#
# Purpose: Eingabe der allgemeinen Daten eines Turnieres.
#
# Preconditions: 
#  Tname,Spielnum knnen Werte beinhalten, mssen aber nicht.
#  Falls sie Werte enthalten, werden diese in der Maske dargestellt.
#  
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die erhaltenen Werte werden im UI dargestellt.
#  Das UI ist ein separates Window. Es wird mit lokalem Grab gearbeitet,
#  d.h., es sind keine anderen Aktionen innerhalb der Anwendung mglich.
#
# Globals:
#
# Returns: 0 : Success
#          1 : Fehler
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Erhalten der TurnierID zur Anzeige 
#
#-------------------------------------------------------

proc ui_turnier_enter { Tid VarTname VarSpielnum ArraySpielleiter } {
   global turdir

   # Pseudoglobals, notwendig, um die Eingabefelder der Maske
   # abzufragen.
   global lTname 
   global lSpielnum 
   global lname 
   global lstr  
   global lwohn 
   global ltele 
   global lfax  
   global lmail 
   global lglobaltid
   global lretval

   upvar $VarTname Tname
   upvar $VarSpielnum Spielnum
   upvar $ArraySpielleiter Spielleiter

   set lTname $Tname
   set lSpielnum $Spielnum
   set lname $Spielleiter(Name)
   set lstr  $Spielleiter(Strasse)
   set lwohn $Spielleiter(Wohnort)
   set ltele $Spielleiter(Telefon)
   set lfax  $Spielleiter(FAX)
   set lmail $Spielleiter(Mail)
   set lglobaltid $Spielleiter(globaltid)
   set lretval 1

   if { [string compare $lname ""] == 0} {
      set Titel "Neues Turnier"
      set Text "Bitte die allgemeinen Daten des neuen Turnieres eingeben."
   } else {
      set Titel "ndern Turnierdaten"
      set Text "Bitte die allgemeinen Daten des Turnieres ndern."
   }

   # Aufbau des UIs
   set w .ui_turnier_enter
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
   
   message $w.msg -text $Text  -aspect 500
                         
   frame $w.frame -bd 3
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill y
               
   button $w.ok -text OK -command "destroy $w; set lretval 0"
   button $w.cancel -text Abbrechen -command "destroy $w; set lretval 1"

   # Turnierinformationen und Turnierleiter
   frame $w.frame.turnier -relief raised -bd 2
   frame $w.frame.leiter  -relief raised -bd 2
   pack $w.frame.turnier $w.frame.leiter -side top -expand yes -fill x

   frame $w.frame.turnier.beschr -relief ridge -bd 2
   frame $w.frame.turnier.anzahl -relief ridge -bd 2
   frame $w.frame.turnier.globaltid -relief ridge -bd 2
   frame $w.frame.turnier.tid -relief ridge -bd 2
   pack $w.frame.turnier.beschr $w.frame.turnier.anzahl $w.frame.turnier.globaltid \
        $w.frame.turnier.tid -side top -anchor nw

   # Eintrag fr Turniername
   label $w.frame.turnier.beschr.text -text {Turnierbezeichnung:}
   entry $w.frame.turnier.beschr.val -relief sunken -width 50 -font fixed \
         -textvariable lTname
   pack $w.frame.turnier.beschr.text -side top -anchor w
   pack $w.frame.turnier.beschr.val -side top -anchor w

   # Eintrag fr Anzahl Spieler
   label $w.frame.turnier.anzahl.text -text {Spieler/Mannschaft:}
   entry $w.frame.turnier.anzahl.val -relief sunken -width 2 -font fixed \
         -textvariable lSpielnum
   pack $w.frame.turnier.anzahl.text -side left -fill x
   pack $w.frame.turnier.anzahl.val -side left

   # Eintrag fr Globale Identifikation
   label $w.frame.turnier.globaltid.text -text {Identifikation:}
   entry $w.frame.turnier.globaltid.val -relief sunken -width 4 -font fixed \
         -textvariable lglobaltid
   pack $w.frame.turnier.globaltid.text -side left -fill x
   pack $w.frame.turnier.globaltid.val -side left
                   
   # Eintrag fr TurnierIdentifikation (Verzeichnis)
   label $w.frame.turnier.tid.text -text "Verzeichnis: $turdir/$Tid"
   pack $w.frame.turnier.tid.text -side left -fill x

   # Eintrag fr Spielleiter
   frame $w.frame.leiter.titel -relief ridge  -bd 2 
   frame $w.frame.leiter.name
   frame $w.frame.leiter.strasse
   frame $w.frame.leiter.wohnort
   frame $w.frame.leiter.telefon
   frame $w.frame.leiter.fax
   frame $w.frame.leiter.mail

   pack $w.frame.leiter.titel -side top -anchor center -fill x
   pack $w.frame.leiter.name -side top   -anchor e
   pack $w.frame.leiter.strasse -side top  -anchor e
   pack $w.frame.leiter.wohnort -side top  -anchor e
   pack $w.frame.leiter.telefon -side top  -anchor e
   pack $w.frame.leiter.fax -side top  -anchor e
   pack $w.frame.leiter.mail -side top  -anchor e

   label $w.frame.leiter.titel.text   -text {Turnierleiter}
   label $w.frame.leiter.name.text    -text {Name:}
   label $w.frame.leiter.strasse.text -text {Strae:}
   label $w.frame.leiter.wohnort.text -text {Wohnort:}
   label $w.frame.leiter.telefon.text -text {Telefon:}
   label $w.frame.leiter.fax.text     -text {FAX:}
   label $w.frame.leiter.mail.text    -text {Mail:}

   entry $w.frame.leiter.name.val    -relief sunken -textvariable lname
   entry $w.frame.leiter.strasse.val -relief sunken -textvariable lstr
   entry $w.frame.leiter.wohnort.val -relief sunken -textvariable lwohn
   entry $w.frame.leiter.telefon.val -relief sunken -textvariable ltele
   entry $w.frame.leiter.fax.val     -relief sunken -textvariable lfax
   entry $w.frame.leiter.mail.val    -relief sunken -textvariable lmail

   pack $w.frame.leiter.titel.text   -side left 
   pack $w.frame.leiter.name.val     -side right -anchor e
   pack $w.frame.leiter.name.text -side right  -anchor e
   pack $w.frame.leiter.strasse.val  -side right -anchor e
   pack $w.frame.leiter.strasse.text  -side right -anchor e
   pack $w.frame.leiter.wohnort.val  -side right -anchor e
   pack $w.frame.leiter.wohnort.text  -side right -anchor e
   pack $w.frame.leiter.telefon.val  -side right -anchor e
   pack $w.frame.leiter.telefon.text  -side right -anchor e
   pack $w.frame.leiter.fax.val      -side right -anchor e
   pack $w.frame.leiter.fax.text      -side right -anchor e
   pack $w.frame.leiter.mail.val     -side right -anchor e
   pack $w.frame.leiter.mail.text     -side left -fill x -anchor e

   pack $w.ok -side left -fill x -expand yes
   pack $w.cancel -side right -fill x -expand yes

   # Lokaler Grab
   update idletask
   grab $w
   tkwait window $w

   if {!$lretval} {
      cn_turnier_move Tname Spielnum Spielleiter
   }
                                
   return $lretval
}


