#============================================================
#
# Procedure: ui_rundenbericht_display
#
# Purpose: Anzeige/Eingabe des Rundenberichtes
#
# Preconditions: 
#  Variable Rundenbericht enthlt den Bericht
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Bericht wird im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#
# Returns: Keine
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Anzeigen des Dateinamens des Rundenberichtes
#
#-------------------------------------------------------

proc ui_rundenbericht_display { Tid Rundenbericht dateiname } {

   set Titel "Rundenbericht"

   # Aufbau des UIs
   set w .ui_rundenbericht_display
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel: $dateiname"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
#   button $w.buttons.save -text Speichern -command "db_meldung_store $Tid $Mid; destroy $w"
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
   pack $w.buttons.cancel -side left -expand true
#   pack $w.buttons.save $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 30
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung der Mannschaftsmeldung
   $w.text insert end $Rundenbericht
}


#============================================================
#
# Procedure: ui_releasenotes_display
#
# Purpose: Anzeige der Releasenotes
#
# Preconditions: 
#  Variable "Releasenotes" enthlt die Releasenotes
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die Release Notes werden im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#
# Returns: Keine
#
#=============================================================

proc ui_releasenotes_display { Releasenotes } {

   set Titel "Release Notes"

   # Aufbau des UIs
   set w .ui_releasenotes_display
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
   pack $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -font fixed -height 30
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung der Releasenotes
   $w.text insert end $Releasenotes
}

#============================================================
#
# Procedure: ui_usersguide_display
#
# Purpose: Anzeige des User Guide
#
# Preconditions: 
#  Variable "Guide" enthlt den User Guide
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Guide wird im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#
# Returns: Keine
#
#=============================================================
                            
proc ui_usersguide_display { Guide } {

   set Titel "User's Guide"

   # Aufbau des UIs
   set w .ui_usersguide_display
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
   pack $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -font fixed -height 30
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung 
   $w.text insert end $Guide
   return 0
}

#============================================================
#
# Procedure: ui_spielplan_anhang_enter
#
# Purpose: Anzeige/Eingabe des Anhanges zum Spielplan
#
# Preconditions: 
#  Turnier mu geffnet sein. Tid enthlt die Turnier-ID
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Anhang wird im UI dargestellt und in Datei
#  gespeichert
#  Das UI ist ein separates Window.
#                          
# Globals:
#
# Returns: Keine
#
#=============================================================

proc ui_spielplan_anhang_enter { Tid } {

   # Holen des evtl. vorhandenen Anhangs

   set s [db_spielplan_anhang_selall $Tid Spielplan_Anhang Dateiname]
   set Titel "Anhang an Spielplan: $Dateiname"

   # Aufbau des UIs
   set w .ui_spielplan_anhang_enter
   catch {destroy $w}
   toplevel $w  
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text "Speichern" -command "db_spielplan_anhang_store $Tid; destroy $w"
   button $w.buttons.cancel -text "Abbrechen" -command "destroy $w"
   pack $w.buttons.save $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 10
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung des Anhang
   $w.text insert end $Spielplan_Anhang
}

#============================================================
#
# Procedure: ui_rundenbericht_anhang_enter
#
# Purpose: Anzeige/Eingabe des Anhanges zum Rundenbericht
#
# Preconditions: 
#  Turnier mu geffnet sein. Tid enthlt die Turnier-ID
#  Runde mu ausgewhlt sein. Runde enthlt die ausgewhlte Runde
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Anhang wird im UI dargestellt und in Datei
#  gespeichert
#  Das UI ist ein separates Window.
#                          
# Globals:
#
# Returns: Keine                                         
#
#=============================================================

proc ui_rundenbericht_anhang_enter { Tid Runde } {
                          
   # Holen des evtl. vorhandenen Anhangs

   set s [db_rundenbericht_anhang_selall $Tid $Runde Runden_Anhang Dateiname]
   set Titel "Anhang an Rundenbericht: $Dateiname"

   # Aufbau des UIs
   set w .ui_rundenbericht_anhang_enter
   catch {destroy $w}
   toplevel $w  
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text "Speichern" -command "db_rundenbericht_anhang_store $Tid $Runde; destroy $w"
   button $w.buttons.cancel -text "Abbrechen" -command "destroy $w"
   pack $w.buttons.save $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 10
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung des Anhang
   $w.text insert end $Runden_Anhang
}


#============================================================
#
# Procedure: ui_turnier_export
#
# Purpose: Anzeige/Eingabe zum Exportieren eines Turnieres
#
# Preconditions: 
#  Turnier darf nicht geffnet sein. Tid enthlt die Turnier-ID
#  des zu exportierenden Turnieres.
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Dateiname, in das das Turnier exportiert werden
#  soll, wird abgefragt.
#  Das UI ist ein separates Window.
#                          
# Globals:
#
# Returns: Keine                                         
#
#=============================================================

proc ui_turnier_export { Tid } {

global G_exportdatei
                     
   set Titel "Exportieren des Turnieres $Tid";
   set Text "Bitte Dateinamen, in den das Turnier exportiert werden soll, angeben und mit \
             OK abschlieen."

   # Aufbau des UIs
   set w .ui_turnier_export
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
   
   message $w.msg -text $Text  -aspect 500
              
   frame $w.frame -bd 3
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill y
               
   button $w.ok -text OK -command "busy { db_turnier_export $Tid}; destroy $w"
   button $w.cancel -text Abbrechen -command "destroy $w"
   
   frame $w.frame.datei
   label $w.frame.datei.text -text {Dateiname:}
   entry $w.frame.datei.val  -relief sunken -width 20 -textvariable G_exportdatei
   
   pack $w.frame.datei -side top
   pack $w.frame.datei.text -side top -anchor w
   pack $w.frame.datei.val -side top -anchor w
   pack $w.ok -side left -fill x -expand yes
   pack $w.cancel -side right -fill x -expand yes
   return 0
}

#============================================================
#
# Procedure: ui_turnier_import
#
# Purpose: Anzeige/Eingabe zum Importieren eines Turnieres
#
# Preconditions: 
#  Turnier darf nicht geffnet sein. Tid enthlt die Turnier-ID
#  des Turnieres, das mit den importierten Daten berschrieben 
#  wird.
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Dateiname, von dem das Turnier importiert werden
#  soll, wird abgefragt.
#  Das UI ist ein separates Window.
#                          
# Globals:
#
# Returns: Keine                                         
#
#=============================================================

proc ui_turnier_import { Tid } {

global G_exportdatei
                     
   set Titel "Importieren des Turnieres $Tid";
   set Text "Bitte Dateinamen, von dem das Turnier geladen werden soll, angeben und mit \
             OK abschlieen."

   # Aufbau des UIs
   set w .ui_turnier_import
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
   
   message $w.msg -text $Text  -aspect 500
              
   frame $w.frame -bd 3
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill y
               
   button $w.ok -text OK -command "busy { db_turnier_import $Tid}; destroy $w"
   button $w.cancel -text Abbrechen -command "destroy $w"
   
   frame $w.frame.datei
   label $w.frame.datei.text -text {Dateiname:}
   entry $w.frame.datei.val  -relief sunken -width 20 -textvariable G_exportdatei
   
   pack $w.frame.datei -side top
   pack $w.frame.datei.text -side top -anchor w
   pack $w.frame.datei.val -side top -anchor w
   pack $w.ok -side left -fill x -expand yes
   pack $w.cancel -side right -fill x -expand yes
   return 0
}
